| Type: | Package |
| Title: | A Collection of Educational Datasets for Research and Statistical Analysis |
| Version: | 0.1.0 |
| Maintainer: | Jorge Luis Marmanillo Santana <jlmarmanillo@gmail.com> |
| Description: | Curates a comprehensive and robust collection of 15 classic educational, economic, and social science datasets meticulously tailored for empirical research, project-based learning, and academic instruction in higher education. It streamlines exploratory data analysis, business intelligence modeling, regression techniques, and hypothesis testing by providing ready-to-use data structures sourced from prominent community packages (Kleiber and Zeileis (2008) https://CRAN.R-project.org/package=AER; Fox and Weisberg (2019) https://CRAN.R-project.org/package=carData). |
| License: | GPL-3 |
| Language: | en |
| URL: | https://github.com/jlmarmanillo-jlms/eduResearchR |
| BugReports: | https://github.com/jlmarmanillo-jlms/eduResearchR/issues |
| Encoding: | UTF-8 |
| LazyData: | true |
| Depends: | R (≥ 4.1.0) |
| Suggests: | ggplot2, testthat (≥ 3.0.0), dplyr, knitr, rmarkdown |
| Config/testthat/edition: | 3 |
| VignetteBuilder: | knitr |
| Config/roxygen2/version: | 8.1.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-09-23 05:03:39 UTC; jlmar |
| Author: | Jorge Luis Marmanillo Santana
|
| Repository: | CRAN |
| Date/Publication: | 2026-10-02 11:50:09 UTC |
CASchools Dataset
Description
California test score data.
Usage
CASchools
Format
Data frame with district-level educational data.
Extracted from the AER package (Christian Kleiber & Achim Zeileis), based on Stock and Watson.
Examples
data(CASchools)
head(CASchools)
CollegeDistance Dataset
Description
Data on high school seniors and college attendance decisions.
Usage
CollegeDistance
Format
Data frame with student-level educational and economic variables.
Econometric data source via the AER package (James H. Stock).
Examples
data(CollegeDistance)
head(CollegeDistance)
EducationLiteracy Dataset
Description
Education and literacy survey metrics.
Usage
EducationLiteracy
Format
Data frame with social science indicators.
Extracted from the carData package (John Fox).
Examples
data(EducationLiteracy)
head(EducationLiteracy)
ExamScores Dataset
Description
Student exam performance metrics.
Usage
ExamScores
Format
Data frame with academic scores and variables.
Extracted from the carData package (John Fox).
Examples
data(ExamScores)
head(ExamScores)
FirstYearGPA Dataset
Description
Academic performance data tracking first year university GPA.
Usage
FirstYearGPA
Format
Data frame with student performance metrics.
Extracted from the carData package (John Fox).
Examples
data(FirstYearGPA)
head(FirstYearGPA)
MathAchieve Dataset
Description
Mathematics achievement scores.
Usage
MathAchieve
Format
Data frame: 7,185 rows, 6 variables.
High School and Beyond study, processed via the MEMSS package (Douglas Bates).
Examples
data(MathAchieve)
head(MathAchieve)
NELS Dataset
Description
National Education Longitudinal study (NELS) of 1988.
Usage
NELS
Format
Data frame: 500 rows, 48 variables.
National Center for Education Statistics (NCES).
Examples
data(NELS)
head(NELS)
STARplus Dataset
Description
STAR participants plus nonexperimental controls.
Usage
STARplus
Format
Data frame: 13,381 rows, 56 variables.
Project STAR, primary investigator Jeremy Finn.
Examples
data(STARplus)
head(STARplus)
STUDENT Dataset
Description
Student survey metrics and statistics.
Usage
STUDENT
Format
Data frame with applied statistics subsets.
OpenIntro Statistics educational data repository.
Examples
data(STUDENT)
head(STUDENT)
apipop Dataset
Description
Student performance in california schools.
Usage
apipop
Format
Data frame: 6,194 rows, 37 variables.
Academic Performance Index, provided via the survey package (Thomas Lumley).
Examples
data(apipop)
head(apipop)
classroom Dataset
Description
classroom data in Chapter 4 of the study of Instructional Improvement.
Usage
classroom
Format
Data frame: 1,190 rows, 12 variables.
Study of Instructional Improvement, research contributor Andrew Raudenbush.
Examples
data(classroom)
head(classroom)
pisausa Dataset
Description
International student assessment data for the USA.
Usage
pisausa
Format
Data frame with assessment scores and demographics.
OECD Programme for International Student Assessment (PISA).
Examples
data(pisausa)
head(pisausa)
school Dataset
Description
Institutional metrics and school performance indicators.
Usage
school
Format
Data frame with institutional data.
U.S. Department of Education (College Scorecard metrics).
Examples
data(school)
head(school)
schoolProgram Dataset
Description
Educational programs and institutional offerings data.
Usage
schoolProgram
Format
Data frame with program characteristics.
U.S. Department of Education.
Examples
data(schoolProgram)
head(schoolProgram)
schools Dataset
Description
Schools data set (NELS-88) for multilevel modeling.
Usage
schools
Format
Data frame: 260 rows, 19 variables.
Schools and Staffing Survey (SASS) / NCES.
Examples
data(schools)
head(schools)